==> gbsite-1.1.1.tar.gz: gbsite/scripts/project/download/ftpuploadsubmit.php <==
<?
    $web_page = "ftpuploadpage";
    include("site_info.php");
	$group_group_id = "upload";

    $web_page = "contextpage";

    if($access_level != 4) {
        $context = "Access Denied!";
        $context_error[] = "You do not have access to upload files to this project.";
    } else {
        unset($filename);
        $already_diffnames = false;
        while(list(,$file) = @each($files)) {
            unset($fname);
                   if(substr($file,-7) == ".tar.gz") {
                $fname = substr($file,0,-7);   
                $tarfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $tarfile_name = $file;
            } else if(substr($file,-4) == ".tgz") {
                $fname = substr($file,0,-4);   
                $tgzfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $tgzfile_name = $file;
            } else if(substr($file,-8) == ".tar.bz2") {
                $fname = substr($file,0,-8);   
                $bz2file = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $bz2file_name = $file;
            } else if(substr($file,-4) == ".zip") {
                $fname = substr($file,0,-4);   
                $zipfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $zipfile_name = $file;
            } else {
                $context_error[] = "Don't recognize the extension on file $file. Please contact <a href=mailto:webmaster@greatbridge.org>webmaster@greatbridge.org</a>";
            }
            if(empty($filename)) $filename = $fname;
            if($fname != $filename && !$already_diffnames) {
                $already_diffnames = true;
                $context_error[] = "The files you have choosen don't all have the same name without their extensions.";
            }
        }
        if(empty($context_error)) {
	    if (down_upload($project_id, $project_name, $branch, $tarfile,
	                    $tarfile_name, $tgzfile, $tgzfile_name, $zipfile,
	                    $zipfile_name, $bz2file, $bz2file_name, $comments,
	                    $member_id)) {
                $context = "Upload Successful.";
                reset($files);
                while(list(,$file) = @each($files)) {
                    system("rm $DOWNLOAD_FILE_PATH/$project_name/incoming/$file");
                }
	    } else {
                $context = "Upload Failed.";
	    }
        }
    }

    include($page_template);
?>

==> gbsite-2.0.0.tar.gz: gbsite/scripts/project/download/ftpuploadsubmit.php <==
<?
    $web_page = "ftpuploadpage";
    include("site_info.php");
	$group_group_id = "upload";

    $web_page = "contextpage";

    if($access_level != 4) {
        $context = "Access Denied!";
        $context_error[] = "You do not have access to upload files to this project.";
    } else {
        unset($filename);
        $already_diffnames = false;
        while(list(,$file) = @each($files)) {
            unset($fname);
                   if(substr($file,-7) == ".tar.gz") {
                $fname = substr($file,0,-7);   
                $tarfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $tarfile_name = $file;
            } else if(substr($file,-4) == ".tgz") {
                $fname = substr($file,0,-4);   
                $tgzfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $tgzfile_name = $file;
            } else if(substr($file,-6) == ".tar.Z") {
                $fname = substr($file,0,-6);
                $tzfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $tzfile_name = $file;
            } else if(substr($file,-8) == ".tar.bz2") {
                $fname = substr($file,0,-8);   
                $bz2file = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $bz2file_name = $file;
            } else if(substr($file,-4) == ".zip") {
                $fname = substr($file,0,-4);   
                $zipfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $zipfile_name = $file;
            } else if(substr($file,-3) == ".gz") {
                $fname = substr($file,0,-3);
                $gzfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $gzfile_name = $file;
            } else if(substr($file,-4) == ".bz2") {
                $fname = substr($file,0,-4);
                $bzfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $bzfile_name = $file;
            } else if(substr($file,-2) == ".Z") {
                $fname = substr($file,0,-2);
                $zfile = $DOWNLOAD_FILE_PATH."/".$project_name."/incoming/".$file;
                $zfile_name = $file;
            } else {
                $context_error[] = "Don't recognize the extension on file $file. Please contact <a href=mailto:webmaster@greatbridge.org>webmaster@greatbridge.org</a>";
            }
            if(empty($filename)) $filename = $fname;
            if($fname != $filename && !$already_diffnames) {
                $already_diffnames = true;
                $context_error[] = "The files you have choosen don't all have the same name without their extensions.";
            }
        }
        if(empty($context_error)) {
	    if (down_upload($project_id, $project_name, $branch, $tarfile,
	                    $tarfile_name, $tgzfile, $tgzfile_name, $zipfile,
	                    $zipfile_name, $bz2file, $bz2file_name, $gzfile,
                            $gzfile_name, $bzfile, $bzfile_name, $zfile,
                            $zfile_name, $tzfile, $tzfile_name, $comments,
	                    $member_id)) {
                $context = "Upload Successful.";
                reset($files);
                while(list(,$file) = @each($files)) {
                    system("rm $DOWNLOAD_FILE_PATH/$project_name/incoming/$file");
                }
	    } else {
                $context = "Upload Failed.";
	    }
        }
    }

    include($page_template);
?>
